@@ -59,6 +59,12 @@ class SimilartyLookupException(AmazonException):
     pass
 
 
+class BrowseNodeLookupException(AmazonException):
+    """Browse Node Lookup Exception.
+    """
+    pass
+
+
 class AmazonAPI(object):
     def __init__(self, aws_key, aws_secret, aws_associate_tag, region="US"):
         """Initialize an Amazon API Proxy.
@@ -141,6 +147,24 @@ class AmazonAPI(object):
             for item in getattr(root.Items, 'Item', [])
         ]
 
+    def browse_node_lookup(self, ResponseGroup="BrowseNodeInfo", **kwargs):
+        """Browse Node Lookup.
+
+        Returns the specified browse node's name, children, and ancestors.
+        Example:
+            >>> api.browse_node_lookup(BrowseNodeId='163357')
+        """
+        response = self.api.BrowseNodeLookup(
+            ResponseGroup=ResponseGroup, **kwargs)
+        root = objectify.fromstring(response)
+        if root.BrowseNodes.Request.IsValid == 'False':
+            code = root.BrowseNodes.Request.Errors.Error.Code
+            msg = root.BrowseNodes.Request.Errors.Error.Message
+            raise BrowseNodeLookupException(
+                "Amazon BrowseNode Lookup Error: '{0}', '{1}'".format(
+                    code, msg))
+        return [AmazonBrowseNode(node.BrowseNode) for node in root.BrowseNodes]
+
     def search(self, **kwargs):
         """Search.
 
@@ -443,10 +467,28 @@ class AmazonProduct(object):
     def author(self):
         """Author.
 
+        Depricated, please use `authors`.
         :return:
-            Author (string)
+            Author (string).
         """
-        return self._safe_get_element_text('ItemAttributes.Author')
+        authors = self.authors
+        if len(authors):
+            return authors[0]
+        else:
+            return None
+
+    @property
+    def authors(self):
+        """Authors.
+
+        :return:
+            Returns of list of authors
+        """
+        result = []
+        authors = self._safe_get_element('ItemAttributes.Author') or []
+        for author in authors:
+            result.append(author.text)
+        return result
 
     @property
     def publisher(self):
@@ -511,6 +553,15 @@ class AmazonProduct(object):
         """
         return self._safe_get_element_text('ItemAttributes.Binding')
 
+    @property
+    def pages(self):
+        """Pages.
+
+        :return:
+            Pages (string)
+        """
+        return self._safe_get_element_text('ItemAttributes.NumberOfPages')
+
     @property
     def publication_date(self):
         """Pubdate.
@@ -527,7 +578,7 @@ class AmazonProduct(object):
         :return:
             Release date (datetime.date)
         """
-        return self._safe_get_element_date('ItemAttributes.PublicationDate')
+        return self._safe_get_element_date('ItemAttributes.ReleaseDate')
 
     @property
     def edition(self):
